diff --git a/functions/utility.py b/functions/utility.py
index ea5afb0d60bbe26047be92b1393b7711b304ce2e..6ed6d26e07673bb8f2238cfdcfbf3d0803c3b19c 100644
--- a/functions/utility.py
+++ b/functions/utility.py
@@ -96,8 +96,8 @@ def cal_mean_and_standard_deviation(data: np.ndarray) -> np.ndarray:
     # DONE #
 
 
-def get_start_end_temprature(
-    temprature_data: np.ndarray, threshold: float
+def get_start_end_temperature(
+    temperature_data: np.ndarray, threshold: float
 ) -> Tuple[float, float]:
     """Calculates the average high and low temperatures from a dataset.
 
@@ -116,7 +116,7 @@ def get_start_end_temprature(
 
     """
     # TODO: Complete the function.
     # Hint: thetemprature_data should contain the raw data of the sensors.
     # numpy.ndarray.flatten() function may be useful for multidimensionale arrays.
     # This line of code throws an exception. This is just to make sure you can see
     # all the code you need to refine. If you already know how to implement the program
@@ -116,7 +116,7 @@ def get_start_end_temprature(
     """
     # TODO: Complete the function.
-    # Hint: thetemprature_data should contain the raw data of the sensors.
+    # Hint: the temperature_data should contain the raw data of the sensors.
     # numpy.ndarray.flatten() function may be useful for multidimensionale arrays.
     # This line of code throws an exception. This is just to make sure you can see